package gov.usgs.earthquake.nshmp.www.meta;

import java.io.InputStream;
import java.util.Map;
import java.util.Properties;

import com.google.common.collect.ImmutableMap;

import gov.usgs.earthquake.nshmp.HazardCalc;

/*
 * Application and model version data. References are string-based as opposed to
 * enum-based (e.g. Edition) to avoid circular references in enum
 * initializations.
 */
class Versions {

  static final String NSHMP_HAZ_VERSION = HazardCalc.VERSION;
  private static final Map<String, String> MODEL_VERSIONS;
  private static final String UNKNOWN = "unknown";

  static {
    ImmutableMap.Builder<String, String> modelMap = ImmutableMap.builder();

    /* Always runs from a war (possibly unpacked). */
    try (InputStream in = Metadata.class.getResourceAsStream("/service.properties")) {
      Properties props = new Properties();
      props.load(in);
      in.close();

      for (String key : props.stringPropertyNames()) {
        String value = props.getProperty(key);
        /* Model versions. */
        modelMap.put(key, value);
      }
    } catch (Exception e) {
      /* Do nothing; probably running outside standard build. */
    }

    MODEL_VERSIONS = modelMap.build();
  }

  static String modelVersion(String id) {
    return MODEL_VERSIONS.getOrDefault(id + ".version", UNKNOWN);
  }

}
